==> 0.4.58.tar.gz: lib/interfaces/setting/mixins/parameter_init_mixin.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:wowit/common.dart';
import 'package:wowit/interfaces/mixins/handle_exception_mixin.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/sql_service.dart';

mixin ParameterInitMixin on HandleExceptionMixin {
  static const String _prefParamter = 'prefParameter';

  static const String _splitValue = '[..]';

  Future initParameter({
    bool reload = false,
    required Function(Map<String, Object> data) init,
  }) async {
    try {
      Map<String, Object> map = await loadParameterFromLocal();
      if (map.isEmpty || reload) {
        map = await loadParameterFromSQL();
        unawaited(saveParameterToLocal(map: map));
        unawaited(updateHasGetParamter());
      }
    } catch (e) {
      handelException(e, subTitle: 'initParameter');
    }
  }

  Future saveParameterToLocal({
    required Map<String, Object> map,
  }) async {
    try {
      SharedPreferences pref = await SharedPreferences.getInstance();
      List<String> list = map.entries
          .map<String>((e) => '${e.key}$_splitValue${e.value}')
          .toList();
      await pref.setStringList(_prefParamter, list);
      if (kDebugMode) {
        print(
          '$runtimeType.saveParameterToLocal success: ${list.length} message',
        );
      }
    } catch (e) {
      handelException(e, subTitle: 'saveParameterToLocal');
    }
  }

  Future<Map<String, Object>> loadParameterFromLocal() async {
    Map<String, Object> map = {};
    try {
      SharedPreferences pref = await SharedPreferences.getInstance();
      List<String> list = pref.getStringList(_prefParamter) ?? [];
      map = {
        for (String item in list)
          item.split(_splitValue).first: item.split(_splitValue).last,
      };
      if (kDebugMode) {
        print(
          '$runtimeType.loadParameterFromLocal success: ${map.length} message',
        );
      }
      return map;
    } catch (e) {
      handelException(e, subTitle: 'loadParameterFromLocal');
      return map;
    }
  }

  Future<Map<String, Object>> loadParameterFromSQL() async {
    Map<String, Object> map = {};
    try {
      Map<String, Object> params = {
        'uid': Common.uid,
      };
      var data = await SQLService.execute('sp_dsParameter', params: params);
      var list = Methods.getList(data, 'tblParameter');
      for (var item in list) {
        String code = Methods.getString(item, 'code');
        Object? value = item['value'];
        if (code.isNotEmpty && value != null) {
          map.putIfAbsent(code, () => value);
        }
      }
      return map;
    } catch (e) {
      handelException(e, subTitle: 'loadParameterFormSQL');
      return map;
    }
  }

  Future updateHasGetParamter() async {
    Map<String, Object> params = {
      'uid': Common.uid,
      'hasGetParamter': true,
    };
    await SQLService.execute(
      'sp_setHasMapData',
      params: params,
    );
  }
}

==> 0.4.72.tar.gz: lib/interfaces/setting/mixins/parameter_init_mixin.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:wowit/common.dart';
import 'package:wowit/interfaces/mixins/handle_exception_mixin.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/sql_service.dart';

mixin ParameterInitMixin on HandleExceptionMixin {
  static const String _prefParamter = 'prefParameter';

  static const String _splitValue = '[..]';

  Future initParameter({
    bool reload = false,
    required Function(Map<String, Object> data) init,
  }) async {
    try {
      Map<String, Object> map = await loadParameterFromLocal();
      if (map.isEmpty || reload) {
        map = await loadParameterFromSQL();
        unawaited(saveParameterToLocal(map: map));
        unawaited(updateHasGetParamter());
      }
    } catch (e) {
      handelException(e, subTitle: 'initParameter');
    }
  }

  Future saveParameterToLocal({
    required Map<String, Object> map,
  }) async {
    try {
      SharedPreferences pref = await SharedPreferences.getInstance();
      List<String> list = map.entries
          .map<String>((e) => '${e.key}$_splitValue${e.value}')
          .toList();
      await pref.setStringList(_prefParamter, list);
      if (kDebugMode) {
        print(
          '$runtimeType.saveParameterToLocal success: ${list.length} message',
        );
      }
    } catch (e) {
      handelException(e, subTitle: 'saveParameterToLocal');
    }
  }

  Future<Map<String, Object>> loadParameterFromLocal() async {
    Map<String, Object> map = {};
    try {
      SharedPreferences pref = await SharedPreferences.getInstance();
      List<String> list = pref.getStringList(_prefParamter) ?? [];
      map = {
        for (String item in list)
          item.split(_splitValue).first: item.split(_splitValue).last,
      };
      if (kDebugMode) {
        print(
          '$runtimeType.loadParameterFromLocal success: ${map.length} message',
        );
      }
      return map;
    } catch (e) {
      handelException(e, subTitle: 'loadParameterFromLocal');
      return map;
    }
  }

  Future<Map<String, Object>> loadParameterFromSQL() async {
    Map<String, Object> map = {};
    try {
      Map<String, Object?> params = {
        'uid': Common.uid,
      };
      var data = await SQLService.execute('sp_dsParameter', params: params);
      var list = Methods.getList(data, 'tblParameter');
      for (var item in list) {
        String code = Methods.getString(item, 'code');
        Object? value = item['value'];
        if (code.isNotEmpty && value != null) {
          map.putIfAbsent(code, () => value);
        }
      }
      return map;
    } catch (e) {
      handelException(e, subTitle: 'loadParameterFormSQL');
      return map;
    }
  }

  Future updateHasGetParamter() async {
    Map<String, Object?> params = {
      'uid': Common.uid,
      'hasGetParamter': true,
    };
    await SQLService.execute(
      'sp_setHasMapData',
      params: params,
    );
  }
}
